==> lugdulov_0.2.1-1.tar.gz: lugdulov-0.2.1/plugins/france/cergypontoise.cpp <==
/*
 * Copyright (C) 2010 Corentin Chary <corentin.chary@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include <QtCore/QDebug>

#include "station.h"
#include "cergypontoise.h"
#include "cergypontoise_p.h"

StationsPluginCergyPontoise::StationsPluginCergyPontoise(QObject *parent)
  : StationsPluginCarto(parent)
{
  d = new StationsPluginCartoPrivateCergypontoise();
}

StationsPluginCergyPontoise::~StationsPluginCergyPontoise()
{
  delete d;
}

QString
StationsPluginCergyPontoise::id() const
{
  return QLatin1String("cergypontoise");
}

QString
StationsPluginCergyPontoise::name() const
{
  return QLatin1String("Cergy-Pontoise");
}

QString
StationsPluginCergyPontoise::bikeName() const
{
  return QLatin1String("Velo2");
}

QIcon
StationsPluginCergyPontoise::bikeIcon() const
{
  return QIcon(":/france/generic.png");
}

==> lugdulov_0.3.0-2.tar.gz: lugdulov-0.3.0/plugins/france/cergypontoise.cpp <==
/*
 * Copyright (C) 2010 Corentin Chary <corentin.chary@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include <QtCore/QDebug>

#include "station.h"
#include "cergypontoise.h"
#include "cergypontoise_p.h"

StationsPluginCergypontoise::StationsPluginCergypontoise(QObject *parent)
  : StationsPluginCycloCity(parent)
{
  d = new StationsPluginSimplePrivateCergypontoise();
}

StationsPluginCergypontoise::~StationsPluginCergypontoise()
{
  delete d;
}

QString
StationsPluginCergypontoise::id() const
{
  return QLatin1String("cergypontoise");
}

QString
StationsPluginCergypontoise::name() const
{
  return QString::fromUtf8("Cergy-Pontoise");
}

QString
StationsPluginCergypontoise::bikeName() const
{
  return QString::fromUtf8("Velo2");
}

QIcon
StationsPluginCergypontoise::bikeIcon() const
{
  return QIcon(":/res/bike.png");
}
